Module cli

Module cli 

Structs

Cli
CompareArgs
ExportLicenseDatasetArgs
ScanArgs
ServeArgs
VerbosityFlags
Reusable -q/-v verbosity flags, flattened into subcommands other than scan (which has its own richer progress modes tied to its output header).

Enums

Command
CompatibilityMode
FailOn
Minimum license-policy compliance severity that fails the build (--fail-on).
ProcessMode
Verbosity
Requested output verbosity for a subcommand.

Functions

run