Module copyright

Module copyright 

Copyright detection module.

Detects copyright statements, holder names, and author information from source code files using a four-stage pipeline:

  1. Text preparation (normalization)
  2. Candidate line selection
  3. Lexing (POS tagging) and parsing (grammar rules)
  4. Refinement and junk filtering

Modules

golden_utils

Structs

AuthorDetection
A detected author name with source location.
CopyrightDetection
A detected copyright statement with source location.
CopyrightDetectionOptions
HolderDetection
A detected copyright holder name with source location.

Functions

detect_copyrights
Detect copyrights, holders, and authors in the given text content.
detect_copyrights_with_options
detect_credits_authors
Detect authors from a CREDITS-formatted file’s content.
is_credits_file
Check if a file path is a CREDITS/AUTHORS file by its filename.
strip_balanced_edge_parens
Strip balanced leading and trailing parentheses from a string.