Module embedded

Module embedded 

Embedded license index loading.

This module provides support for loading a build-time generated license index that is embedded in the binary. This eliminates the runtime dependency on the ScanCode rules directory.

The embedded artifact is generated during the build process and contains serialized LoadedRule and LoadedLicense values.

Modules

schema
Schema definitions for the embedded loader artifact.