pub struct KnownToken {
pub id: TokenId,
pub kind: TokenKind,
pub is_digit_only: bool,
pub is_short_or_digit: bool,
}Fields
id: TokenIdkind: TokenKindis_digit_only: boolis_short_or_digit: boolTrait Implementations
Sourceimpl Archive for KnownToken
impl Archive for KnownToken
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedKnownToken
type Archived = ArchivedKnownToken
The archived representation of this type. Read more
Sourcetype Resolver = KnownTokenResolver
type Resolver = KnownTokenResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl Clone for KnownToken
impl Clone for KnownToken
Sourcefn clone(&self) -> KnownToken
fn clone(&self) -> KnownToken
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for KnownToken
impl Debug for KnownToken
Sourceimpl<'de> Deserialize<'de> for KnownToken
impl<'de> Deserialize<'de> for KnownToken
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<__D: Fallible + ?Sized> Deserialize<KnownToken, __D> for Archived<KnownToken>
impl<__D: Fallible + ?Sized> Deserialize<KnownToken, __D> for Archived<KnownToken>
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<KnownToken, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<KnownToken, <__D as Fallible>::Error>
Deserializes using the given deserializer
Sourceimpl Hash for KnownToken
impl Hash for KnownToken
Sourceimpl PartialEq for KnownToken
impl PartialEq for KnownToken
Sourcefn eq(&self, other: &KnownToken) -> bool
fn eq(&self, other: &KnownToken) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for KnownToken
impl Serialize for KnownToken
impl Copy for KnownToken
impl Eq for KnownToken
impl StructuralPartialEq for KnownToken