pub struct TokenMetadata {
pub kind: TokenKind,
pub is_digit_only: bool,
pub is_short_or_digit: bool,
}Fields
kind: TokenKindis_digit_only: boolis_short_or_digit: boolTrait Implementations
Sourceimpl Archive for TokenMetadata
impl Archive for TokenMetadata
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedTokenMetadata
type Archived = ArchivedTokenMetadata
The archived representation of this type. Read more
Sourcetype Resolver = TokenMetadataResolver
type Resolver = TokenMetadataResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl Clone for TokenMetadata
impl Clone for TokenMetadata
Sourcefn clone(&self) -> TokenMetadata
fn clone(&self) -> TokenMetadata
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TokenMetadata
impl Debug for TokenMetadata
Sourceimpl<'de> Deserialize<'de> for TokenMetadata
impl<'de> Deserialize<'de> for TokenMetadata
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<__D: Fallible + ?Sized> Deserialize<TokenMetadata, __D> for Archived<TokenMetadata>
impl<__D: Fallible + ?Sized> Deserialize<TokenMetadata, __D> for Archived<TokenMetadata>
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<TokenMetadata, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<TokenMetadata, <__D as Fallible>::Error>
Deserializes using the given deserializer
Sourceimpl Serialize for TokenMetadata
impl Serialize for TokenMetadata
impl Copy for TokenMetadata