pub struct License {Show 29 fields
pub key: String,
pub short_name: Option<String>,
pub name: String,
pub language: Option<String>,
pub spdx_license_key: Option<String>,
pub other_spdx_license_keys: Vec<String>,
pub category: Option<String>,
pub owner: Option<String>,
pub homepage_url: Option<String>,
pub text: String,
pub reference_urls: Vec<String>,
pub osi_license_key: Option<String>,
pub text_urls: Vec<String>,
pub osi_url: Option<String>,
pub faq_url: Option<String>,
pub other_urls: Vec<String>,
pub notes: Option<String>,
pub is_deprecated: bool,
pub is_exception: bool,
pub is_unknown: bool,
pub is_generic: bool,
pub replaced_by: Vec<String>,
pub minimum_coverage: Option<u8>,
pub standard_notice: Option<String>,
pub ignorable_copyrights: Option<Vec<String>>,
pub ignorable_holders: Option<Vec<String>>,
pub ignorable_authors: Option<Vec<String>>,
pub ignorable_urls: Option<Vec<String>>,
pub ignorable_emails: Option<Vec<String>>,
}Expand description
License metadata loaded from .LICENSE files.
Fields
key: Stringshort_name: Option<String>name: Stringlanguage: Option<String>spdx_license_key: Option<String>other_spdx_license_keys: Vec<String>category: Option<String>owner: Option<String>homepage_url: Option<String>text: Stringreference_urls: Vec<String>osi_license_key: Option<String>text_urls: Vec<String>osi_url: Option<String>faq_url: Option<String>other_urls: Vec<String>notes: Option<String>is_deprecated: boolis_exception: boolis_unknown: boolis_generic: boolreplaced_by: Vec<String>minimum_coverage: Option<u8>standard_notice: Option<String>ignorable_copyrights: Option<Vec<String>>ignorable_holders: Option<Vec<String>>ignorable_urls: Option<Vec<String>>ignorable_emails: Option<Vec<String>>Trait Implementations
Sourceimpl Archive for License
impl Archive for License
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedLicense
type Archived = ArchivedLicense
The archived representation of this type. Read more
Sourcetype Resolver = LicenseResolver
type Resolver = LicenseResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl<'de> Deserialize<'de> for License
impl<'de> Deserialize<'de> for License
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<__D: Fallible + ?Sized> Deserialize<License, __D> for Archived<License>where
String: Archive,
<String as Archive>::Archived: Deserialize<String, __D>,
Option<String>: Archive,
<Option<String> as Archive>::Archived: Deserialize<Option<String>, __D>,
Vec<String>: Archive,
<Vec<String> as Archive>::Archived: Deserialize<Vec<String>, __D>,
bool: Archive,
<bool as Archive>::Archived: Deserialize<bool, __D>,
Option<u8>: Archive,
<Option<u8> as Archive>::Archived: Deserialize<Option<u8>, __D>,
Option<Vec<String>>: Archive,
<Option<Vec<String>> as Archive>::Archived: Deserialize<Option<Vec<String>>, __D>,
impl<__D: Fallible + ?Sized> Deserialize<License, __D> for Archived<License>where
String: Archive,
<String as Archive>::Archived: Deserialize<String, __D>,
Option<String>: Archive,
<Option<String> as Archive>::Archived: Deserialize<Option<String>, __D>,
Vec<String>: Archive,
<Vec<String> as Archive>::Archived: Deserialize<Vec<String>, __D>,
bool: Archive,
<bool as Archive>::Archived: Deserialize<bool, __D>,
Option<u8>: Archive,
<Option<u8> as Archive>::Archived: Deserialize<Option<u8>, __D>,
Option<Vec<String>>: Archive,
<Option<Vec<String>> as Archive>::Archived: Deserialize<Option<Vec<String>>, __D>,
impl StructuralPartialEq for License