pub enum PositionSpan {
Range {
start: usize,
end: usize,
},
Discrete(Vec<usize>),
}Variants
Implementations
Sourceimpl PositionSpan
impl PositionSpan
pub fn range(start: usize, end: usize) -> Self
pub fn new(start: usize, end: usize) -> Self
pub fn from_positions(positions: impl IntoIterator<Item = usize>) -> Self
pub fn empty() -> Self
pub fn iter(&self) -> SpanIter<'_> ⓘ
pub fn len(&self) -> usize
pub fn is_empty(&self) -> bool
pub fn bounds(&self) -> (usize, usize)
pub fn contains(&self, pos: usize) -> bool
pub fn overlaps_set(&self, set: &PositionSet) -> bool
pub fn to_position_set(&self) -> PositionSet
pub fn to_vec(&self) -> Vec<usize>
Sourcepub fn is_contiguous(&self) -> bool
pub fn is_contiguous(&self) -> bool
Returns true if the positions form a contiguous range with no gaps.
This is always true for Range variants, and checks adjacency for Discrete.