pub struct PositionSpan { /* private fields */ }Expand description
A span representing a range of token positions.
Used for tracking matched token positions and performing position arithmetic. This is a single continuous range of token positions (start..=end, inclusive).
Distinct from spans::Span which tracks multiple byte ranges for coverage.
Based on Python Span class at: reference/scancode-toolkit/src/licensedcode/spans.py
Implementations