pub struct LicenseDetection {
pub license_expression: Option<String>,
pub license_expression_spdx: Option<String>,
pub matches: Vec<LicenseMatch>,
pub detection_log: Vec<String>,
pub identifier: Option<String>,
}Expand description
A LicenseDetection combines one or more LicenseMatch objects using various rules and heuristics.
Fields
license_expression: Option<String>A license expression string using SPDX license expression syntax and ScanCode license keys - the effective license expression for this detection.
license_expression_spdx: Option<String>SPDX license expression string with SPDX ids only.
matches: Vec<LicenseMatch>List of license matches combined in this detection.
detection_log: Vec<String>A list of detection log entries explaining how this detection was created.
identifier: Option<String>An identifier unique for a license detection, containing the license expression and a UUID crafted from the match contents.