pub enum DatasourceId {
Show 159 variants
AboutFile,
Readme,
EtcOsRelease,
AlpineApkArchive,
AlpineApkbuild,
AlpineInstalledDb,
ArchAurinfo,
ArchPkginfo,
ArchSrcinfo,
AndroidAarLibrary,
AndroidApk,
Axis2Mar,
Axis2ModuleXml,
AutotoolsConfigure,
BazelBuild,
BazelModule,
BowerJson,
BuckFile,
BuckMetadata,
BunLock,
BunLockb,
CargoLock,
CargoToml,
ChefCookbookMetadataJson,
ChefCookbookMetadataRb,
CocoapodsPodfile,
CocoapodsPodfileLock,
CocoapodsPodspec,
CocoapodsPodspecJson,
ConanConanDataYml,
ConanConanFilePy,
ConanConanFileTxt,
ConanLock,
CondaYaml,
CondaMetaJson,
CondaMetaYaml,
ClojureDepsEdn,
ClojureProjectClj,
CpanDistIni,
CpanMakefile,
CpanManifest,
CpanMetaJson,
CpanMetaYml,
CranDescription,
PubspecLock,
PubspecYaml,
DebianControlExtractedDeb,
DebianControlInSource,
DebianCopyright,
DebianDeb,
DebianSourceMetadataTarball,
DebianDistrolessInstalledDb,
DebianInstalledFilesList,
DebianInstalledMd5Sums,
DebianInstalledStatusDb,
DebianMd5SumsInExtractedDeb,
DebianOriginalSourceTarball,
DebianSourceControlDsc,
DenoJson,
DenoLock,
Dockerfile,
FreebsdCompactManifest,
Godeps,
GoMod,
GoModGraph,
GoSum,
GoWork,
HackageCabal,
HackageCabalProject,
HackageStackYaml,
BuildGradle,
GradleLockfile,
GradleModule,
HaxelibJson,
HelmChartLock,
HelmChartYaml,
HexMixLock,
AntIvyXml,
JavaEarApplicationXml,
JavaEarArchive,
JavaJar,
JavaJarManifest,
JavaOsgiManifest,
JavaWarArchive,
JavaWarWebXml,
JbossSar,
JbossServiceXml,
MavenPom,
MavenPomProperties,
MesonBuild,
SbtBuildSbt,
MicrosoftCabinet,
MicrosoftUpdateManifestMum,
AppleDmg,
ChromeCrx,
IosIpa,
MozillaXpi,
MeteorPackage,
NpmPackageJson,
NpmPackageLockJson,
NugetCsproj,
NugetDepsJson,
NugetDirectoryBuildProps,
NugetDirectoryPackagesProps,
NugetNupkg,
NugetProjectJson,
NugetProjectLockJson,
NugetPackagesConfig,
NugetPackagesLock,
NugetNuspec,
NugetVbproj,
NugetFsproj,
OpamFile,
PhpComposerJson,
PhpComposerLock,
PnpmLockYaml,
PnpmWorkspaceYaml,
Pipfile,
PipfileLock,
PipRequirements,
PixiLock,
PixiToml,
PypiPipOriginJson,
PypiEgg,
PypiInspectDeplock,
PypiJson,
PypiPoetryLock,
PypiPylockToml,
PypiPyprojectToml,
PypiSdistPkginfo,
PypiSetupCfg,
PypiSetupPy,
PypiUvLock,
PypiWheel,
PypiWheelMetadata,
RpmArchive,
RpmInstalledDatabaseBdb,
RpmInstalledDatabaseNdb,
RpmInstalledDatabaseSqlite,
RpmMarinerManifest,
RpmPackageLicenses,
RpmSpecfile,
RpmYumdb,
Gemfile,
GemfileLock,
GemArchive,
GemArchiveExtracted,
Gemspec,
InstallshieldInstaller,
IsoDiskImage,
NsisInstaller,
SharShellArchive,
SquashfsDiskImage,
SwiftPackageManifestJson,
SwiftPackageResolved,
SwiftPackageShowDependencies,
VcpkgJson,
YarnLock,
Gitmodules,
}Expand description
Unique identifier for the type of package data source (file format).
Datasource IDs distinguish between different file types within the same ecosystem
(e.g., NpmPackageJson vs NpmPackageLockJson). The assembly system uses these
IDs to match packages from related files for merging into a single logical package.
Serialization
Variants serialize to snake_case strings matching the Python reference values. The JSON output is identical to the Python ScanCode Toolkit.
Examples
use provenant::models::DatasourceId;
let id = DatasourceId::NpmPackageJson;
assert_eq!(id.as_ref(), "npm_package_json");
assert_eq!(id.to_string(), "npm_package_json");Variants
AboutFile
Readme
EtcOsRelease
AlpineApkArchive
AlpineApkbuild
AlpineInstalledDb
ArchAurinfo
ArchPkginfo
ArchSrcinfo
AndroidAarLibrary
AndroidApk
Axis2Mar
Axis2ModuleXml
AutotoolsConfigure
BazelBuild
BazelModule
BowerJson
BuckFile
Matches Python reference value. More consistent name would be buck_file.
BuckMetadata
Matches Python reference value. More consistent name would be buck_metadata.
BunLock
BunLockb
CargoLock
CargoToml
ChefCookbookMetadataJson
Matches Python reference value.
ChefCookbookMetadataRb
Matches Python reference value.
CocoapodsPodfile
CocoapodsPodfileLock
CocoapodsPodspec
CocoapodsPodspecJson
ConanConanDataYml
ConanConanFilePy
ConanConanFileTxt
ConanLock
CondaYaml
Matches Python reference value.
CondaMetaJson
CondaMetaYaml
ClojureDepsEdn
ClojureProjectClj
CpanDistIni
CpanMakefile
Matches Python reference value.
CpanManifest
CpanMetaJson
CpanMetaYml
CranDescription
PubspecLock
PubspecYaml
DebianControlExtractedDeb
DebianControlInSource
DebianCopyright
DebianDeb
DebianSourceMetadataTarball
Matches Python reference value.
DebianDistrolessInstalledDb
DebianInstalledFilesList
Matches Python reference value.
DebianInstalledMd5Sums
DebianInstalledStatusDb
DebianMd5SumsInExtractedDeb
DebianOriginalSourceTarball
Matches Python reference value.
DebianSourceControlDsc
DenoJson
DenoLock
Dockerfile
FreebsdCompactManifest
Godeps
GoMod
GoModGraph
GoSum
GoWork
HackageCabal
HackageCabalProject
HackageStackYaml
BuildGradle
GradleLockfile
GradleModule
HaxelibJson
HelmChartLock
HelmChartYaml
HexMixLock
AntIvyXml
JavaEarApplicationXml
JavaEarArchive
JavaJar
JavaJarManifest
JavaOsgiManifest
JavaWarArchive
JavaWarWebXml
JbossSar
JbossServiceXml
MavenPom
MavenPomProperties
MesonBuild
SbtBuildSbt
MicrosoftCabinet
MicrosoftUpdateManifestMum
AppleDmg
ChromeCrx
IosIpa
MozillaXpi
MeteorPackage
NpmPackageJson
NpmPackageLockJson
NugetCsproj
NugetDepsJson
NugetDirectoryBuildProps
NugetDirectoryPackagesProps
NugetNupkg
NugetProjectJson
NugetProjectLockJson
NugetPackagesConfig
NugetPackagesLock
NugetNuspec
Serializes to "nuget_nupsec" to match Python reference value (typo in original).
NugetVbproj
NugetFsproj
OpamFile
PhpComposerJson
PhpComposerLock
PnpmLockYaml
PnpmWorkspaceYaml
Pipfile
PipfileLock
PipRequirements
PixiLock
PixiToml
PypiPipOriginJson
PypiEgg
PypiInspectDeplock
PypiJson
PypiPoetryLock
PypiPylockToml
PypiPyprojectToml
PypiSdistPkginfo
PypiSetupCfg
PypiSetupPy
PypiUvLock
PypiWheel
PypiWheelMetadata
RpmArchive
RpmInstalledDatabaseBdb
RpmInstalledDatabaseNdb
RpmInstalledDatabaseSqlite
RpmMarinerManifest
RpmPackageLicenses
RpmSpecfile
Serializes to "rpm_spefile" to match Python reference value (typo in original).
RpmYumdb
Gemfile
GemfileLock
GemArchive
GemArchiveExtracted
Matches Python reference value.
Gemspec
InstallshieldInstaller
IsoDiskImage
NsisInstaller
SharShellArchive
SquashfsDiskImage
SwiftPackageManifestJson
SwiftPackageResolved
SwiftPackageShowDependencies
VcpkgJson
YarnLock
Gitmodules
Implementations