pub enum PackageType {
Show 69 variants
About,
Alpm,
Alpine,
Android,
AndroidLib,
Autotools,
Axis2,
Bazel,
Bitbake,
Bower,
Buck,
Cab,
Cargo,
Carthage,
Chef,
Chrome,
Cocoapods,
Composer,
Conan,
Conda,
Cpan,
Cran,
Dart,
Deb,
Deno,
Docker,
Dmg,
Ear,
Freebsd,
Gem,
Generic,
Github,
Golang,
Hackage,
Haxe,
Helm,
Hex,
Installshield,
Julia,
Ios,
Iso,
Ivy,
Jar,
JbossService,
LinuxDistro,
Maven,
Meson,
Meteor,
Nix,
Mozilla,
Npm,
Nsis,
Nuget,
Opam,
Osgi,
PnpmLock,
Pubspec,
Pypi,
Pixi,
Publiccode,
Readme,
Rpm,
Shar,
Squashfs,
Swift,
Vcpkg,
War,
Winexe,
WindowsUpdate,
}Expand description
Package ecosystem/registry type identifier.
Identifies the package manager or ecosystem a package belongs to
(e.g., npm, PyPI, Maven, Cargo). Used as the "type" field in
ScanCode Toolkit-compatible JSON output.
This enum includes both standard purl types and ScanCode-specific types
for file format recognizers (e.g., Jar, War) and metadata sources
(e.g., About, Readme). For the official list of standardized purl types, see:
https://github.com/package-url/purl-spec/blob/main/purl-types-index.json
Serialization
Variants serialize to lowercase/kebab-case strings matching the Python reference values. The JSON output is identical to the Python ScanCode Toolkit.
Examples
ⓘ
use provenant::models::PackageType;
let pt = PackageType::Npm;
assert_eq!(pt.as_ref(), "npm");
assert_eq!(pt.to_string(), "npm");Variants
About
Alpm
Alpine
Android
AndroidLib
Autotools
Axis2
Bazel
Bitbake
Bower
Buck
Cab
Cargo
Carthage
Chef
Chrome
Cocoapods
Composer
Conan
Conda
Cpan
Cran
Dart
Deb
Deno
Docker
Dmg
Ear
Freebsd
Gem
Generic
Github
Golang
Hackage
Haxe
Helm
Hex
Installshield
Julia
Ios
Iso
Ivy
Jar
JbossService
LinuxDistro
Maven
Meson
Meteor
Nix
Mozilla
Npm
Nsis
Nuget
Opam
Osgi
PnpmLock
Pubspec
Pypi
Pixi
Publiccode
Readme
Rpm
Shar
Squashfs
Swift
Vcpkg
War
Winexe
WindowsUpdate
Implementations