Module file

Module file 

Enums

ExtractedTextKind

Functions

decode_bytes_to_string
Decode a byte buffer to a String, trying UTF-8 first, then Latin-1.
extract_printable_strings
extract_text_for_detection
get_creation_date
Get the creation date of a file or directory as an RFC3339 string.
is_path_excluded
Check if a path should be excluded based on a list of glob patterns.