Module hash

Module hash 

Functions

calculate_buffer_hashes
Computes sha1, md5, sha256 and git-sha1 for an in-memory buffer in a single chunked pass that updates every hasher per chunk, improving cache locality over four independent full passes over the same bytes.
calculate_file_hashes
calculate_md5
calculate_sha1
calculate_sha1_git
calculate_sha256