Module sourcemap

Module sourcemap 

Source map file processing for scanner text detection.

Source map files (.js.map, .css.map) are JSON files containing embedded source code in a sourcesContent array. This module extracts that content so the scanner can detect licenses and parties from the embedded sources instead of from the raw source map JSON wrapper.

Functions

detection_text
Return the text scanners should inspect for this file.
extract_sourcemap_content
Extract source content from a source map JSON file.
is_sourcemap
Check if a file is a source map file based on extension.