Structs
- Author
- Copyright
- Dependency
- Package dependency information with version constraints.
- Extra
Data - Additional counters and environment details for a scan run.
- File
Info - File-level scan result containing metadata and detected findings.
- File
Info Builder - Builder for
FileInfo. - File
Reference - Reference to a file within a package archive with checksums.
- Header
- Scan execution metadata stored in
output.headers. - Holder
- License
Clarity Score - License
Detection - License detection result containing matched license expressions.
- License
Reference - Reference entry for a detected license.
- License
Rule Reference - Reference metadata for a license detection rule.
- Match
- Individual license text match with location and confidence score.
- Output
- Top-level ScanCode-compatible JSON payload.
- Output
Email - OutputURL
- Package
- Top-level assembled package, created by merging one or more
PackageDataobjects from related manifest/lockfiles (e.g., package.json + package-lock.json). - Package
Data - Package metadata extracted from manifest files.
- Party
- Author, maintainer, or contributor information.
- Resolved
Package - Summary
- System
Environment - Host environment information captured during scan execution.
- Tally
Entry - TopLevel
Dependency - Top-level dependency instance, created during package assembly.
Enums
- Datasource
Id - Unique identifier for the type of package data source (file format).
- File
Type - Package
Type - Package ecosystem/registry type identifier.