pub struct Match {Show 15 fields
pub license_expression: String,
pub license_expression_spdx: String,
pub from_file: Option<String>,
pub start_line: LineNumber,
pub end_line: LineNumber,
pub matcher: Option<String>,
pub score: MatchScore,
pub matched_length: Option<usize>,
pub match_coverage: Option<f64>,
pub rule_relevance: Option<u8>,
pub rule_identifier: Option<String>,
pub rule_url: Option<String>,
pub matched_text: Option<String>,
pub matched_text_diagnostics: Option<String>,
pub referenced_filenames: Option<Vec<String>>,
}Expand description
Individual license text match with location and confidence score.
Represents a specific region of text that matched a known license pattern.
Fields
license_expression: Stringlicense_expression_spdx: Stringfrom_file: Option<String>start_line: LineNumberend_line: LineNumbermatcher: Option<String>score: MatchScorematched_length: Option<usize>match_coverage: Option<f64>rule_relevance: Option<u8>rule_identifier: Option<String>rule_url: Option<String>matched_text: Option<String>matched_text_diagnostics: Option<String>referenced_filenames: Option<Vec<String>>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for Match
impl<'de> Deserialize<'de> for Match
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<&Match> for OutputMatch
impl From<&Match> for OutputMatch
Sourceimpl TryFrom<&OutputMatch> for Match
impl TryFrom<&OutputMatch> for Match
impl StructuralPartialEq for Match