PackageData

Struct PackageData 

pub struct PackageData {
Show 42 fields pub package_type: Option<PackageType>, pub namespace: Option<String>, pub name: Option<String>, pub version: Option<String>, pub qualifiers: Option<HashMap<String, String>>, pub subpath: Option<String>, pub primary_language: Option<String>, pub description: Option<String>, pub release_date: Option<String>, pub parties: Vec<Party>, pub keywords: Vec<String>, pub homepage_url: Option<String>, pub download_url: Option<String>, pub size: Option<u64>, pub sha1: Option<Sha1Digest>, pub md5: Option<Md5Digest>, pub sha256: Option<Sha256Digest>, pub sha512: Option<Sha512Digest>, pub bug_tracking_url: Option<String>, pub code_view_url: Option<String>, pub vcs_url: Option<String>, pub copyright: Option<String>, pub holder: Option<String>, pub declared_license_expression: Option<String>, pub declared_license_expression_spdx: Option<String>, pub license_detections: Vec<LicenseDetection>, pub other_license_expression: Option<String>, pub other_license_expression_spdx: Option<String>, pub other_license_detections: Vec<LicenseDetection>, pub extracted_license_statement: Option<String>, pub notice_text: Option<String>, pub source_packages: Vec<String>, pub file_references: Vec<FileReference>, pub is_private: bool, pub is_virtual: bool, pub extra_data: Option<HashMap<String, Value>>, pub dependencies: Vec<Dependency>, pub repository_homepage_url: Option<String>, pub repository_download_url: Option<String>, pub api_data_url: Option<String>, pub datasource_id: Option<DatasourceId>, pub purl: Option<String>,
}
Package metadata extracted from manifest files.

Compatible with ScanCode Toolkit output format. Contains standardized package information including name, version, dependencies, licenses, and other metadata. This is the primary data structure returned by all parsers.

Fields

package_type: Option<PackageType>namespace: Option<String>name: Option<String>version: Option<String>qualifiers: Option<HashMap<String, String>>subpath: Option<String>primary_language: Option<String>description: Option<String>release_date: Option<String>parties: Vec<Party>keywords: Vec<String>homepage_url: Option<String>download_url: Option<String>size: Option<u64>sha1: Option<Sha1Digest>md5: Option<Md5Digest>sha256: Option<Sha256Digest>sha512: Option<Sha512Digest>bug_tracking_url: Option<String>code_view_url: Option<String>vcs_url: Option<String>copyright: Option<String>holder: Option<String>declared_license_expression: Option<String>declared_license_expression_spdx: Option<String>license_detections: Vec<LicenseDetection>other_license_expression: Option<String>other_license_expression_spdx: Option<String>other_license_detections: Vec<LicenseDetection>extracted_license_statement: Option<String>notice_text: Option<String>source_packages: Vec<String>file_references: Vec<FileReference>is_private: boolis_virtual: boolextra_data: Option<HashMap<String, Value>>dependencies: Vec<Dependency>repository_homepage_url: Option<String>repository_download_url: Option<String>api_data_url: Option<String>datasource_id: Option<DatasourceId>purl: Option<String>

Implementations

Source

impl PackageData

pub fn get_license_expression(&self) -> Option<String>

Extracts a single license expression from all license detections in this package. Returns None if there are no license detections.