CondaEnvironmentYmlParser

Struct CondaEnvironmentYmlParser 

pub struct CondaEnvironmentYmlParser;
Conda environment file (environment.yml, conda.yaml) parser.

Extracts dependencies from Conda environment files used to define reproducible environments. Supports both Conda and pip dependencies, with channel specifications.