pub struct HaxeParser;Expand description
Haxe package manifest (haxelib.json) parser.
Extracts package metadata, dependencies, and contributor information from standard JSON haxelib.json manifest files used by the Haxe package manager.