Enums
Functions
- decode_
bytes_ to_ string - Decode a byte buffer to a String, trying UTF-8 first, then Latin-1.
- extract_
printable_ strings - extract_
text_ for_ detection - get_
creation_ date - Get the creation date of a file or directory as an RFC3339 string.
- is_
path_ excluded - Check if a path should be excluded based on a list of glob patterns.