Source map file processing for scanner text detection.
Source map files (.js.map, .css.map) are JSON files containing embedded
source code in a sourcesContent array. This module extracts that content
so the scanner can detect licenses and parties from the embedded sources
instead of from the raw source map JSON wrapper.
Functions
- detection_
text - Return the text scanners should inspect for this file.
- extract_
sourcemap_ content - Extract source content from a source map JSON file.
- is_
sourcemap - Check if a file is a source map file based on extension.